{pkgs, lib, ...}: let
  username = "nibunta";
in
{
  # Import things like programs, shells, core configurations, etc
  # imports = [./modules ];
  # imports = import ./modules;
  imports = [
    ./modules/libs/python.nix

    # ./modules/programs/librewolf
    # ./modules/programs/github-desktop.nix
    # ./modules/programs/pycharm-pro.nix
    ./modules/programs/vscodium.nix

    # ./modules/programs/virtualbox.nix
    # ./modules/shells/zsh.nix 
  ];

  manual.manpages.enable = true;
  home = {
    stateVersion = "22.11";
    
    inherit username;
    # homeDirectory = "/home/${username}/";
    # configuration.imports = [./home.nix];

    packages = with pkgs; [
      # System control
      btop wget
      gsmartcontrol
      xclip nodePackages.remod-cli
      gparted fsearch

      virt-manager libvirt spice-vdagent #qemu_kvm
      # linuxKernel.packages.linux_latest_libre.virtualbox
      # virtualboxHardened linuxKernel.packages.linux_6_3.virtualbox 
      
      # Web
      librewolf
      thunderbird

      # IDE Tools
      kate
      jetbrains.pycharm-professional jetbrains.clion
      imhex

      # Version control
      git
      gittyup # lazygit # github-desktop gitkraken
      
      # Engines & LSPs
      nodejs nodePackages.pnpm yarn nodePackages.yo nodePackages.generator-code
      rustup
      # lua 
      lua-language-server luajit luau

      # I think this is for Python MkDocs, should be in a shell.nix
      # for its own project instead
      # cairo cairomm python3.10-CairoSVG python3.11-pip


      # Archiving & Libs
      file unzip unar
      lzo lzop

      # Credentials
      keepassxc

      # Games
      pcsx2
      gzdoom enyo-launcher

      # Notes & Organization & Drafting
      obsidian
      typst typst-lsp

      # Comunication
      signal-desktop

      # KDE Apps
      spectacle ark okular kcalc
      kooha # Recording and Editing
      
      # Dev & General Utils
      websocat nmap direnv

      # Input aidware
      xorg.xev xorg.xmodmap
      # input-remapper # Aidware, using xorg instead

      # Emulation and Compatibility
      wine

      # Debian Packages Supports
      dpkg patchelf # binutil

      # temurin-jrs-bin-17
      # Unfree packages
      gitkraken
      /*
      {
        pkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName) [
          # jetbrains-toolbox # IDE Tools
          # jetbrains.pycharm-professional
        ];
      }
      */
    ];
  };


  programs = {
    home-manager.enable = true;
  };

  # TODO: In case a new mouse is plugged, this setting could be
  #       reverted back to original, so make it with that in mind
  #       when figured out how to execute this command optionally
  home.file.".config/.xmodmap".text = "
    xmodmap -e \"pointer = 1 2 8 4 5 6 7 3 8 10\"
  ";

  # Keyboard Lights Mapping,
  # https://ubuntuforums.org/showthread.php?t=2257710  link for context
  # home.file."./config/.xmodmap".source = "
  #  xmodmap -e \"add mod3 = Scroll_Lock\"
  #  xset -led named \"Scroll Lock\"
  #";
}

